@@ -81,10 +81,18 @@ def tokens_to_string(tokens):
         # filling space between tokens
         line += ' '*(token.index - shift - len(line))
 
-        # add token
-        line += token.value
+        match token.type:
+            case 'VARIABLE':
+                token_value = '@' + token.value
+            case 'SYSTEM_VARIABLE':
+                token_value = '@@' + token.value
+            case _:
+                token_value = token.value
 
-        last_pos = token.index + len(token.value)
+        # add token
+        line += token_value
+
+        last_pos = token.index + len(token_value)
 
     # last line
     content += line
@@ -143,3 +151,25 @@ def dump_json(obj) -> str:
         return "true" if obj else "false"
 
     return dump_json(str(obj))
+
+
+def dump_using_dict(using: dict | None) -> str | None:
+    from mindsdb_sql_parser.ast.select import Identifier
+    from mindsdb_sql_parser.ast.select.operation import Object
+
+    if using is None:
+        return None
+    using_ar = []
+    for key, value in using.items():
+        if isinstance(value, Object):
+            args = [
+                f'{k}={dump_json(v)}'
+                for k, v in value.params.items()
+            ]
+            args_str = ', '.join(args)
+            value = f'{value.type}({args_str})'
+        else:
+            value = dump_json(value)
+
+        using_ar.append(f'{Identifier(key).to_string()}={value}')
+    return ', '.join(using_ar)
\ No newline at end of file
